@@ -20,7 +20,7 @@ SORT_DIR_VALUES = ('asc', 'desc')
 
 SHARE_SORT_KEY_VALUES = (
     'id', 'status', 'size', 'host', 'share_proto',
-    'availability_zone',
+    'availability_zone_id', 'availability_zone',
     'user_id', 'project_id',
     'created_at', 'updated_at',
     'display_name', 'name',
@@ -97,6 +97,7 @@ STATUS_MANAGE_ERROR = 'manage_error'
 STATUS_UNMANAGE_ERROR = 'unmanage_error'
 STATUS_DELETING = 'deleting'
 STATUS_CREATING = 'creating'
+STATUS_SERVER_MIGRATING = 'server_migrating'
 
 SNAPSHOT_SUPPORT = 'snapshot_support'
 CREATE_SHARE_FROM_SNAPSHOT_SUPPORT = 'create_share_from_snapshot_support'
@@ -109,3 +110,6 @@ BOOL_SPECS = (
     REVERT_TO_SNAPSHOT_SUPPORT,
     MOUNT_SNAPSHOT_SUPPORT
 )
+
+REPLICA_GRADUATION_VERSION = '2.56'
+REPLICA_PRE_GRADUATION_VERSION = '2.55'
