@@ -53,7 +53,7 @@ class TestShareSnapshot(manila_fakes.TestShare):
         self.snapshots_mock = self.app.client_manager.share.share_snapshots
         self.snapshots_mock.reset_mock()
         self.app.client_manager.share.api_version = api_versions.APIVersion(
-            "2.51")
+            api_versions.MAX_VERSION)
 
         self.export_locations_mock = (
             self.app.client_manager.share.share_snapshot_export_locations)
@@ -283,8 +283,8 @@ class TestShareSnapshotShow(TestShareSnapshot):
         ]
         parsed_args = self.check_parser(self.cmd, arglist, verifylist)
 
-        cliutils.transform_export_locations_to_string_view = mock.Mock()
-        cliutils.transform_export_locations_to_string_view.return_value = (
+        cliutils.convert_dict_list_to_string = mock.Mock()
+        cliutils.convert_dict_list_to_string.return_value = (
             self.export_location)
 
         columns, data = self.cmd.take_action(parsed_args)
