@@ -74,17 +74,17 @@ class QuotaSetManager(base.ManagerWithFind):
                             resource_path=RESOURCE_PATH_LEGACY)
 
     @api_versions.wraps("2.7", "2.24")  # noqa
-    def get(self, tenant_id, user_id=None, detail=False):
+    def get(self, tenant_id, user_id=None, detail=False):  # noqa
         return self._do_get(tenant_id, user_id,
                             resource_path=RESOURCE_PATH)
 
     @api_versions.wraps("2.25", "2.38")  # noqa
-    def get(self, tenant_id, user_id=None, detail=False):
+    def get(self, tenant_id, user_id=None, detail=False):  # noqa
         return self._do_get(tenant_id, user_id, detail=detail,
                             resource_path=RESOURCE_PATH)
 
     @api_versions.wraps("2.39")  # noqa
-    def get(self, tenant_id, user_id=None, share_type=None, detail=False):
+    def get(self, tenant_id, user_id=None, share_type=None, detail=False):   # noqa
         return self._do_get(
             tenant_id, user_id, share_type=share_type, detail=detail,
             resource_path=RESOURCE_PATH)
@@ -95,6 +95,7 @@ class QuotaSetManager(base.ManagerWithFind):
                    force=None, user_id=None, share_type=None,
                    share_groups=None, share_group_snapshots=None,
                    share_replicas=None, replica_gigabytes=None,
+                   per_share_gigabytes=None,
                    resource_path=RESOURCE_PATH):
         self._check_user_id_and_share_type_args(user_id, share_type)
         body = {
@@ -110,6 +111,7 @@ class QuotaSetManager(base.ManagerWithFind):
                 'force': force,
                 'share_replicas': share_replicas,
                 'replica_gigabytes': replica_gigabytes,
+                'per_share_gigabytes': per_share_gigabytes,
             },
         }
 
@@ -141,7 +143,7 @@ class QuotaSetManager(base.ManagerWithFind):
         )
 
     @api_versions.wraps("2.7", "2.38")  # noqa
-    def update(self, tenant_id, shares=None, snapshots=None, gigabytes=None,
+    def update(self, tenant_id, shares=None, snapshots=None, gigabytes=None,  # noqa
                snapshot_gigabytes=None, share_networks=None, force=None,
                user_id=None):
         return self._do_update(
@@ -156,7 +158,7 @@ class QuotaSetManager(base.ManagerWithFind):
                 "not share type.")
 
     @api_versions.wraps("2.39", "2.39")  # noqa
-    def update(self, tenant_id, user_id=None, share_type=None,
+    def update(self, tenant_id, user_id=None, share_type=None,  # noqa
                shares=None, snapshots=None, gigabytes=None,
                snapshot_gigabytes=None, share_networks=None, force=None):
         self._validate_st_and_sn_in_same_request(share_type, share_networks)
@@ -168,7 +170,7 @@ class QuotaSetManager(base.ManagerWithFind):
         )
 
     @api_versions.wraps("2.40", "2.52")  # noqa
-    def update(self, tenant_id, user_id=None, share_type=None,
+    def update(self, tenant_id, user_id=None, share_type=None,  # noqa
                shares=None, snapshots=None, gigabytes=None,
                snapshot_gigabytes=None, share_networks=None,
                share_groups=None, share_group_snapshots=None,
@@ -183,8 +185,8 @@ class QuotaSetManager(base.ManagerWithFind):
             resource_path=RESOURCE_PATH,
         )
 
-    @api_versions.wraps(REPLICA_QUOTAS_MICROVERSION)  # noqa
-    def update(self, tenant_id, user_id=None, share_type=None,
+    @api_versions.wraps(REPLICA_QUOTAS_MICROVERSION, "2.61")  # noqa
+    def update(self, tenant_id, user_id=None, share_type=None,  # noqa
                shares=None, snapshots=None, gigabytes=None,
                snapshot_gigabytes=None, share_networks=None,
                share_groups=None, share_group_snapshots=None,
@@ -201,6 +203,26 @@ class QuotaSetManager(base.ManagerWithFind):
             resource_path=RESOURCE_PATH
         )
 
+    @api_versions.wraps("2.62")  # noqa
+    def update(self, tenant_id, user_id=None, share_type=None,  # noqa
+               shares=None, snapshots=None, gigabytes=None,
+               snapshot_gigabytes=None, share_networks=None,
+               share_groups=None, share_group_snapshots=None,
+               share_replicas=None, replica_gigabytes=None, force=None,
+               per_share_gigabytes=None):
+        self._validate_st_and_sn_in_same_request(share_type, share_networks)
+        return self._do_update(
+            tenant_id, shares, snapshots, gigabytes, snapshot_gigabytes,
+            share_networks, force, user_id,
+            share_type=share_type,
+            share_groups=share_groups,
+            share_group_snapshots=share_group_snapshots,
+            share_replicas=share_replicas,
+            replica_gigabytes=replica_gigabytes,
+            per_share_gigabytes=per_share_gigabytes,
+            resource_path=RESOURCE_PATH
+        )
+
     @api_versions.wraps("1.0", "2.6")
     def defaults(self, tenant_id):
         return self._get(
@@ -209,7 +231,7 @@ class QuotaSetManager(base.ManagerWithFind):
             "quota_set")
 
     @api_versions.wraps("2.7")  # noqa
-    def defaults(self, tenant_id):
+    def defaults(self, tenant_id):  # noqa
         return self._get(
             "%(resource_path)s/%(tenant_id)s/defaults" % {
                 "resource_path": RESOURCE_PATH, "tenant_id": tenant_id},
@@ -238,10 +260,10 @@ class QuotaSetManager(base.ManagerWithFind):
             tenant_id, user_id, resource_path=RESOURCE_PATH_LEGACY)
 
     @api_versions.wraps("2.7", "2.38")  # noqa
-    def delete(self, tenant_id, user_id=None):
+    def delete(self, tenant_id, user_id=None):  # noqa
         return self._do_delete(tenant_id, user_id, resource_path=RESOURCE_PATH)
 
     @api_versions.wraps("2.39")  # noqa
-    def delete(self, tenant_id, user_id=None, share_type=None):
+    def delete(self, tenant_id, user_id=None, share_type=None):   # noqa
         return self._do_delete(
             tenant_id, user_id, share_type, resource_path=RESOURCE_PATH)
